/*
 * (C) Copyright 2000
 * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 * Ulrich Lutz, Speech Design GmbH, ulutz@datalab.de.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include <common.h>
#include <mpc8xx.h>
#include <commproc.h>

/* ------------------------------------------------------------------------- */

static long int dram_size (long int, long int *, long int);

/* ------------------------------------------------------------------------- */

#define	_NOT_USED_	0xFFFFFFFF



const uint sdram_table[] =
{
	/* DRAM single read. (offset 0-7 in UPM RAM) */
    .long 0x0FF3CC24, 0x0FF3CC04, 0x0CF3CC04, 0x00F3CC04,            
    .long 0x00F3CC00, 0x37F7CC47, 0xFFFFFFFF, 0xFFFFFFFF,
/* DRAM burst read. (offset 8-17 in UPM RAM) */
    .long  0x8FFFCC24, 0x0FFFCC04, 0x0CFFCC04, 0x00FFCC04,
    .long  0x00FFCC08, 0x0CFFCC44, 0x00FFEC0C, 0x03FFEC00,
    .long  0x00FFEC44, 0x00FFCC08, 0x0CFFCC44, 0x00FFEC04,
    .long  0x00FFEC00, 0x3FFFEC47, 0xFFFEFFFF, 0xFFFFFFFF,
/* DRAM single write. (offset 18-1F in UPM RAM) */
    .long 0x0FAFCC24, 0x0FAFCC04, 0x08AFCC04, 0x00AFCC00,            
    .long 0x37FFCC47, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,         
/* DRAM burst write. (offset 20-2F in UPM RAM) */
    .long 0x0FAFCC24, 0x0FAFCC04, 0x08AFCC00, 0x07AFCC4C,            
    .long 0x08AFCC00, 0x07AFCC4C, 0x08AFCC00, 0x07AFCC4C,            
    .long 0x08AFCC00, 0x372FCC47, 0xFFFFFFFF, 0xFFFFFFFF,            
    .long 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,         
/* DRAM Refresh timer expired (offset 30-3B in UPM RAM) */
    .long 0xE0FFCC84, 0x00FFCC04, 0x00FFCC04, 0x0FFFCC04,             
    .long 0x7FFFCC04, 0xFFFFCC86, 0xFFFFCC05, 0xFFFFFFFF,             
    .long 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,             
/* DRAM Exception. (offset 3c-3f in UPM RAM) */
    .long 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF

};

/* ------------------------------------------------------------------------- */


/*
 * Check Board Identity:
 *
 */

int checkboard (void)
{
	puts ("Board: WindRiver MDP PRO\n");
	return (0);
}

/* ------------------------------------------------------------------------- */

long int
initdram (int board_type)
{
    volatile immap_t     *immap  = (immap_t *)CFG_IMMR;
    volatile memctl8xx_t *memctl = &immap->im_memctl;
    long int size_b0;


    /*
     * Map controller bank 2 to the SRAM bank at preliminary address.
     */
    
    /* Configure DRAM at UMB */
    upmconfig(UPMB, (uint *)sdram_table, sizeof(sdram_table)/sizeof(uint));
	
	memctl->memc_or2 = CFG_OR2;
    memctl->memc_br2 = CFG_BR2;
    memctl->memc_or3 = CFG_OR3;
    memctl->memc_br3 = CFG_BR3;
    
	memctl->memc_mptpr = CFG_MPTPR;
	
	memctl->memc_mbmr = CFG_MBMR;	/* refresh not enabled yet */
    
	memctl->memc_mar = 0x00000088;

    /*
     * Map controller bank 3 to the SDRAM bank at preliminary address.
     */
     
    udelay(200);
    memctl->memc_mcr = 0x80804105;
    udelay(1);
    memctl->memc_mcr = 0x80804130;
    udelay(1);
    memctl->memc_mcr = 0x80804130;
    udelay(1);
    memctl->memc_mcr = 0x80804106;
    
    /*
     * Check Bank 0 Memory Size for re-configuration
     */
    size_b0 = 0x01000000; 

    
    return (size_b0);
}

